## Ruleset Builder 5E Ruleset
These files use the Ruleset Builder Plugin to implement the DND 5E system rules for malee attacks,
ranged attack, magic attacks, healing, saves, skill checks, and opposed skill checks. Rules include
range checks, support for Advantage/Normal/Disadvantage rolls, disadvantage rolls due to range,
automatic critical roll damage adjustment, vulnerability damage adjustments, reduction damage
adjustment, resistance damage adjustment and immunity damage adjustment.

## Change Log
```
1.0.0: Initial release
```

## Installing With R2ModMan

Install using R2ModMan or similar modding manager.

## Usage

Ruleset comes with a sample Jon and Goblin character. To try the ruleset, add two minis and then
rename one to Jon and the other to Goblin.

Limitation: You may need to re-load the board after renaming the minis. This will be addressed in the
next release of the Ruleset Builder plugin.

Select a mini and then make selection from the added Ruleset menus.

### 5E Ruleset Action Sequences

The following Action Seqeunces are available in the 5E Ruleset. Each is briefly described below including
which option on Jon can be used to view an example of the Action Sequence.

#### 5E.Attack.json

This Action Seqeunce is used to make an attack against a victim's AC. This Action Sequence is used for all
attacks against AC including melee weapons, ranged weapons and magic attack (that hit against AC). This
Action Seqeunce includes the selection of a victim, checks range, rolls the attack, and determines the
success or failure of the attack.

Examples: 

``Jon | Melee Attacks | Axe``
``Jon | Ranged Attacks | Shortbow``
``Jon | Magic | Firebolt``

Configuration:
```
"Block01.Name": "Attack",			"Block01.Parameters": {"Attack": "+5", "ShortRange": "5", "LongRange": "5", "Effect": "STR contest to disarm"}, 
```

#### 5E.Damage.json

This Action Seqeunce is used to roll damage, apply critical damage modification if the roll is a critical hit,
applies vulnerabilities damage modification (if applicable), applies immunity damage modifcation (if applicable),
applies reduction damage modification (if applicable), applies resistance damage modifcation (if applicable),
and prepares data for the damage report. This block is skipped if the attack failed. A complete Action Block
may have more than one Damage Action Sequence if the weapon does multiple types of damage (see Axe example).

Examples: 

``Jon | Melee Attacks | Axe``
``Jon | Ranged Attacks | Shortbow``
``Jon | Magic | Firebolt``

Configuration:
```
"Block02.Name": "Damage",			"Block02.Parameters": {"CriticalRange": "20", "Damage": "1D6+4", "DamageType": "Slashing"},
```

#### 5E.DamageReport.json

This Action Seqeunce is used to display the results of damage inflcited. It collects a summary of the damage
inflicted, all damage modifications if any, and sends the appropriate information to all of the appropriate
targets. In addition, this Action Seqeunce performs the actual adjustment of the victim's HP by the damage
amount.

Limitation: No check for HP under 0 (which can be useful to check for instant death). No check for dying.

Examples: 

``Jon | Melee Attacks | Axe``
``Jon | Ranged Attacks | Shortbow``
``Jon | Magic | Firebolt``

Configuration:
```
"Block03.Name": "DamageReport",		"Block03.Parameters": {} 
```

#### 5E.Heal.json

This Action Sequence is used to cast healing spells which increase the HP of the victim.

Examples:

``Jon | Magic | Healing Word``
``Jon | Magic | Cure Wounds``

Configuration:
```
"Block01.Name": "Heal",				"Block01.Parameters": {"Name": "Healing Word", "Formula": "1D4+1", "Range": "60", "Effect": ""}
```

#### 5E.JustDamage.json

This Action Seqeunce is used to roll damage without any associated victim interactions. Typically used for
spells like Fireball or Sleep since there is no multiple target selection ruleset at this time.

Examples:

``Jon | Magic | Fireball``

Configuration:
```
"Block01.Name": "JustDamage",		"Block01.Parameters": {"Name": "Fireball", "CriticalRange": "20", "Damage": "8D6", "DamageType": "Fire", "Effect": "DEX DC14 Save: 1/2 Damage"}
```

#### 5E.Lookup.json

This Action Sequence is used to pass instructions to the Lookup Plugin if present. Typically used for spells
that other effects than damage in order to look them up and display them to the chat for reference.

Note: Lookup Plugin isn't listed as a official dependency for this plugin so that it does not have to be used.
However, if you wish to use this feature then you will need to install Lookup Plugin if it isn't already installed.

Examples:

``Jon | Magic | Find-Familiar``

Configuration:
```
"Block01.Name": "Lookup",			"Block01.Parameters": {"Name": "Find-Familiar" }
```

#### 5E.Magic.json

This Action Seqeunce is used to make an attack with save. This Action Seqeunce includes the selection of a victim,
checks range, rolls the save, and determines the success or failure of the spell. It also sets up a dummy conditions
for the Action Sequence to be able to call on the Damage and DamageReport Action Seqeunces (even though there was no
attack against AC).

Examples: 

``Jon | Magic | Frostbite``

Configuration:
```
"Block01.Name": "Magic",			"Block01.Parameters": {"Name": "Frostbite", "DC": "13", "Save": "CON", "Range": "120", "Effect": "Target has disadvantage on the next weapon attack roll until next turn"},
```

#### 5E.SaveCheck.json

This Action Seqeunce is used to make a save. This Action Seqeunce can be used if the Instigator is not using a Ruleset
rule to initiate the spell attack or for situation where there is no instigator such as a trap. These entries are not
only used to make Save but they are also used to determine the save modifier when the character is a victim of a spell.
As such these should be included on characters even if those characters are not going to be initiating save rolls from
the character radial menu.

Examples: 

``Jon | Saves | DEX``

Configuration:
```
"Block01.Name": "SaveCheck", "Block01.Parameters": {"Save": "DEX", "Modifier": "+4"}
```

#### 5E.SkillCheck.json

This Action Seqeunce is used to make a non-opposed skill roll. 

Examples: 

``Jon | Skills | Athletics``

Configuration:
```
"Block01.Name": "SkillCheck",	 		"Block01.Parameters": { "Skill": "Athletics", "Modifier": "+1"}
```

#### 5E.SkillCheckOpposed.json

This Action Seqeunce is used to make a opposed skill roll. Includes the selection of a victim. First the instigator
rolls the skill check and then the victim rolls the opposed skills check. The results of the opposed skill check is
determined. 

Examples: 

``Jon | Skills | Stealth Opposed``

Configuration:
```
"Block01.Name": "SkillCheckOpposed",	"Block01.Parameters": { "Skill": "Stealth", "Modifier": "+4", "OpposedSkill": "Perception" }
```

### 5E Ruleset Demo

The Ruleset Builder 5E Ruleset comes with a Jon and Goblin character. Besides being examples where the rulesets can be
demonstrated, these files (especially the Jon file) is the best source for making your own character. Just copy the Jon
file and modify the numbers, weapon names and spell names.

Limitation:

Becuase a board re-load may be necessary after minis are renamed, ideally all minis should placed on the board in advance
with the correct names so that when the board is loaded all the character data is retrieved properly. This will likely be
fixed in the next Ruleset Builder Plugin release.